@@ -1055,7 +1055,7 @@ extern "C" {
         void (*focus_done) (GDigicamManager *manager,
                            GDigicamFocusmodestatus status);
         gboolean (*pict_done) (GDigicamManager *manager,
-                               GString *filename);
+                               const gchar *filename);
 	void (*capture_start) (GDigicamManager *manager);
 
 	void (*capture_end) (GDigicamManager *manager);
@@ -1065,6 +1065,10 @@ extern "C" {
 	void (*image_preview) (GDigicamManager *manager, GdkPixbuf *value);
 
 	void (*internal_error) (GDigicamManager *manager);
+
+	void (*io_error) (GDigicamManager *manager);
+
+	void (*no_space_error) (GDigicamManager *manager);
     };
 
 
